#!/bin/bash
# get screen name to rotate
if [[ "$1" != "Wacom" && "$1" != "Laptop" ]]
then
	echo "usage: rotate-devices.sh Wacom|Laptop"
	exit 1
fi

source $HOME/.config/wacomtodisplays.sh
[ $? -eq 0 ] || create-mapwacom-config.sh
source $HOME/.config/wacomtodisplays.sh

if [[ "$1" == "Wacom" ]]
then
	WACOM_ID=$(xsetwacom --list | grep One | head -1 |  sed 's/^.*id: //' | sed 's/	.*$//')
else
	WACOM_ID=$(xsetwacom --list | grep -v One | head -1 |  sed 's/^.*id: //' | sed 's/	.*$//')
fi

if [ ! ${SCREENCONFIG[$WACOM_ID]} ]
then
	kdialog --error "It seems you have no device that is configured to work with: $1..."
	exit 1
fi
currentscreen=${SCREENCONFIG[$WACOM_ID]} 

currentrotation=$(xrandr --current --verbose | grep $currentscreen | egrep -o ' (normal|left|inverted|right)' | head -1 | sed 's/ //')

case $currentrotation in
    left)  # Currently top is rotated left, we should set it normal (0°)
	  xrandr --output $currentscreen --rotate normal
	  for j in $(xsetwacom --list | sed 's/^.*id: //' | sed 's/	.*$//')
	  do
		if [ "${SCREENCONFIG[$j]}" = "$currentscreen" ]; then
			xsetwacom set $j Rotate none
		fi
	  done
	  ;;
    normal)  # Screen is not rotated, we should rotate it right (90°)
	   xrandr --output $currentscreen --rotate right
	  for j in $(xsetwacom --list | sed 's/^.*id: //' | sed 's/	.*$//')
	  do
		if [ "${SCREENCONFIG[$j]}" = "$currentscreen" ]; then
			xsetwacom set $j Rotate cw
		fi
	  done
	   ;;
    right)    # Top of screen is rotated right, we should invert it (180°)
	   xrandr --output $currentscreen --rotate inverted
	  for j in $(xsetwacom --list | sed 's/^.*id: //' | sed 's/	.*$//')
	  do
		if [ "${SCREENCONFIG[$j]}" = "$currentscreen" ]; then
			xsetwacom set $j Rotate half
		fi
	  done
	   ;;
    inverted)  # Screen is inverted, we should rotate it left (270°)
	   xrandr --output $currentscreen --rotate left
	  for j in $(xsetwacom --list | sed 's/^.*id: //' | sed 's/	.*$//')
	  do
		if [ "${SCREENCONFIG[$j]}" = "$currentscreen" ]; then
			xsetwacom set $j Rotate ccw
		fi
	  done
	   ;;
    *)
	   echo "Unknown orientation" >&2
	   exit 1
	   ;;
esac

mapwacom.sh
